@@ -198,7 +198,7 @@ int main (void)
         Pixmap cursor_pic;
         XColor cursor_fg, cursor_bg;
         XFontStruct* font_info;
-        char* font_name = "*-helvetica-*-12-*";
+        char* font_name = "*freemono*";
         char str[256];   
         unsigned int cursor_width, cursor_height;
         int hotspot_x, hotspot_y;
@@ -234,7 +234,7 @@ int main (void)
         unsigned long black_pixel;
 
 
-        display = XOpenDisplay(":0");
+        display = XOpenDisplay(getenv("DISPLAY"));
         if (display == NULL) {
                 fprintf(stderr, "Cannot connect to X server %s\n", ":0");
                 exit(-1);
@@ -553,7 +553,7 @@ int main (void)
         /*
           Put results to file and screen
         */
-        out_file = fopen("out.txt", "w");
+        out_file = fopen("/etc/evtouch/config", "w");
         
 
         /* 
@@ -566,11 +566,10 @@ int main (void)
                min_max.max_x, 
                min_max.max_y);
 
-        fprintf(out_file, "        Option        \"MinX\"        \"%d\"\n", min_max.min_x);
-        fprintf(out_file, "        Option        \"MinY\"        \"%d\"\n", min_max.min_y);
-        fprintf(out_file, "        Option        \"MaxX\"        \"%d\"\n", min_max.max_x);
-        fprintf(out_file, "        Option        \"MaxY\"        \"%d\"\n", min_max.max_y);
-
+        fprintf(out_file, "MINX=\"%d\"\n", min_max.min_x);
+        fprintf(out_file, "MINY=\"%d\"\n", min_max.min_y);
+        fprintf(out_file, "MAXX=\"%d\"\n", min_max.max_x);
+        fprintf(out_file, "MAXY=\"%d\"\n", min_max.max_y);
 
         for (i=0; i<9; i++) {
 
@@ -602,7 +601,7 @@ int main (void)
                        i, marker_coordinates[i][1]-click_coordinates[i][1]);
 
 
-                fprintf(out_file, "        Option        \"x%d\"        \"%d\"\n        Option        \"y%d\"        \"%d\"\n",
+                fprintf(out_file, "X%d=\"%d\"\nY%d=\"%d\"\n",
                         i, marker_coordinates[i][0]-click_coordinates[i][0],
                         i, marker_coordinates[i][1]-click_coordinates[i][1]);
         }
