@@ -81,11 +81,13 @@
 #define NEED_XF86_TYPES	/* for xisb.h when !XFree86LOADER */
 #endif
 
-#include "compiler.h"
+#define DBG(lvl, f) {if ((lvl) <= debug_level) f;}
 
+#include "compiler.h"
 #include "xisb.h"
 
 #include <linux/input.h>
+
 /*****************************************************************************
  *        Local Headers
  ****************************************************************************/
@@ -105,6 +107,18 @@ static InputInfoPtr
 EVTouchPreInit(InputDriverPtr drv, IDevPtr dev, int flags);
 static void
 EVTouchPtrCtrl(DeviceIntPtr device, PtrCtrl *ctrl);
+static Bool
+ConvertProc ( LocalDevicePtr local,
+              int first,
+              int num,
+              int v0,
+              int v1,
+              int v2,
+              int v3,
+              int v4,
+              int v5,
+              int *x,
+              int *y );
 
 static int debug_level = 0;
 
@@ -119,15 +133,6 @@ InputDriverRec EVTOUCH = {
 };
 
 #ifdef XFree86LOADER
-ModuleInfoRec EVTouchInfo = {
-        1,
-        "EVTOUCH",
-        NULL,
-        0,
-        NULL /*EVTouchAvailableOptions*/,
-};
-
-
 static XF86ModuleVersionInfo VersionRec =
 {
         "evtouch",
@@ -135,7 +140,7 @@ static XF86ModuleVersionInfo VersionRec =
         MODINFOSTRING1,
         MODINFOSTRING2,
         XF86_VERSION_CURRENT,
-        0, 8, 7,
+        0, 8, 8,
         ABI_CLASS_XINPUT,
         ABI_XINPUT_VERSION,
         MOD_CLASS_XINPUT,
@@ -150,7 +155,6 @@ Plug( pointer module,
       int *errmaj,
       int *errmin )
 {
-        xf86AddModuleInfo(&EVTouchInfo, module);
         xf86AddInputDriver(&EVTOUCH, module, 0);
         return module;
 }
@@ -288,19 +292,31 @@ static void SetBtnAction(EVTouchPrivatePtr priv, int btn, int action)
 void EVTouchProcessAbs(EVTouchPrivatePtr priv)
 {
         struct input_event *ev; /* packet being/just read */
-
+        int pos_changed = 0;
         ev = &priv->ev;
 
         if ( (ev->code == ABS_X) || (ev->code == ABS_Z) ) {
-                priv->cur_x = ev->value;
-		libtouchSetXPos(priv->libtouch, priv->cur_x);
+                priv->raw_x = ev->value;
+                pos_changed = 1;
 	}
 
         if ( (ev->code == ABS_Y) || (ev->code == ABS_RX) ) {
-                priv->cur_y = ev->value;
-		libtouchSetYPos(priv->libtouch, priv->cur_y);
+                priv->raw_y = ev->value;
+                pos_changed = 1;
 	}
 
+        if (pos_changed == 1) {
+#if GET_ABI_MAJOR(ABI_XINPUT_VERSION) == 2
+                ConvertProc(priv->local, 0, 2, 
+                            priv->raw_x, priv->raw_y,
+                            0, 0, 0, 0, 
+                            &priv->cur_x, &priv->cur_y);
+#endif
+
+		libtouchSetPos(priv->libtouch, priv->cur_x, priv->cur_y);
+		return;
+        }
+
 	if (ev->code == ABS_WHEEL) {
 		LocalDevicePtr local = priv->local;
 
@@ -336,24 +352,30 @@ void EVTouchProcessAbs(EVTouchPrivatePtr priv)
 void EVTouchProcessRel(EVTouchPrivatePtr priv)
 {
         struct input_event *ev; /* packet being/just read */
+        int dummy;
 
         ev = &priv->ev;
         if ( ev->code == REL_X ) {
-                priv->cur_x += ev->value;
-                if (priv->cur_x > priv->max_x)
-                        priv->cur_x = priv->max_x;
-                if (priv->cur_x < priv->min_x)
-                        priv->cur_x = priv->min_x;
-                return;
+                priv->raw_x += ev->value;
+                if (priv->raw_x > priv->max_x)
+                        priv->raw_x = priv->max_x;
+                if (priv->raw_x < priv->min_x)
+                        priv->raw_x = priv->min_x;
         } 
         if ( ev->code == REL_Y ) {
-                priv->cur_y += ev->value;
-                if (priv->cur_y > priv->max_y)
-                        priv->cur_y = priv->max_y;
-                if (priv->cur_y < priv->min_y)
-                        priv->cur_y = priv->min_y;
-                return;
+                priv->raw_y += ev->value;
+                if (priv->raw_y > priv->max_y)
+                        priv->raw_y = priv->max_y;
+                if (priv->raw_y < priv->min_y)
+                        priv->raw_y = priv->min_y;
         }
+
+#if GET_ABI_MAJOR(ABI_XINPUT_VERSION) == 2
+        ConvertProc(priv->local, 0, 2,
+                    priv->raw_x, priv->raw_y,
+                    0, 0, 0, 0,
+                    &priv->cur_x, &priv->cur_y);
+#endif
 	
         libtouchSetPos(priv->libtouch, priv->cur_x, priv->cur_y);
 }
@@ -616,8 +638,8 @@ DeviceInit (DeviceIntPtr dev)
         DBGOUT(2, "EVTouch: %s btn_count=%d\n", __FUNCTION__, 
                priv->btn_count);
         priv->btn_actions = xcalloc(priv->btn_count, sizeof(BtnAction));
-        xf86memset(priv->btn_actions, 0, 
-                   priv->btn_count * sizeof(BtnAction));
+        memset(priv->btn_actions, 0, 
+               priv->btn_count * sizeof(BtnAction));
         
         DBGOUT(2, "EVTouch: %s btn_count=%d\n", __FUNCTION__, 
                priv->btn_count);
@@ -638,20 +660,27 @@ DeviceInit (DeviceIntPtr dev)
                 return !Success;
         }
 
-        xf86InitValuatorAxisStruct(dev, 0, priv->min_x, priv->max_x,
+#if GET_ABI_MAJOR(ABI_XINPUT_VERSION) == 2
+        xf86InitValuatorAxisStruct(dev, 0, 0, priv->screen_width,
                                    1024,
                                    EV_AXIS_MIN_RES /* min_res */ ,
                                    EV_AXIS_MAX_RES /* max_res */ );
         xf86InitValuatorDefaults(dev, 0);
-        xf86InitValuatorAxisStruct(dev, 1, priv->min_y, priv->max_y,
+        xf86InitValuatorAxisStruct(dev, 1, 0, priv->screen_height,
                                    1024,
                                    EV_AXIS_MIN_RES /* min_res */ ,
                                    EV_AXIS_MAX_RES /* max_res */ );
         xf86InitValuatorDefaults(dev, 1);
+#else
+	xf86InitValuatorAxisStruct(dev, 0, priv->min_x, priv->max_x,
+        xf86InitValuatorDefaults(dev, 1);
+#endif
 
         /* Initial position of pointer on screen: Centered */
         priv->cur_x=(priv->max_x - priv->min_x)/2;
         priv->cur_y=(priv->max_y - priv->min_y)/2;
+	priv->raw_x=priv->cur_x;
+	priv->raw_y=priv->cur_y;
         libtouchSetPos(priv->libtouch, priv->cur_x, priv->cur_y);
 
         
@@ -708,7 +737,7 @@ DeviceControl (DeviceIntPtr dev,
 static void
 EVTouchNewPacket (EVTouchPrivatePtr priv)
 {
-        xf86memset(&priv->ev, 0, sizeof(struct input_event));
+        memset(&priv->ev, 0, sizeof(struct input_event));
         priv->packeti = 0;
         priv->binary_pkt = FALSE;
 }
@@ -781,7 +810,7 @@ static void ReadInput (LocalDevicePtr local)
                                     priv->screen_num, 
                                     priv->cur_x, 
                                     priv->cur_y);
-                        
+
                 xf86PostProximityEvent(local->dev, 1, 0, 2,
                                        priv->cur_x,
                                        priv->cur_y);
@@ -906,13 +935,14 @@ ConvertProc ( LocalDevicePtr local,
 
         DBGOUT(2, "EVTouch: FIRST: v0=%d   v1=%d\n", v0, v1);
 
-        /*correction of raw coordinates*/
-        if ( (priv->fifo>0) && (priv->calibrate) ){
+	/*write raw coordinates to fifo for calibration programm*/
+        if ( (priv->fifo > 0) && (priv->calibrate) ){
                 DBGOUT(2, "EVTouch: writing to FIFO\n");
                 write (priv->fifo, &v0, sizeof(v0));
                 write (priv->fifo, &v1, sizeof(v1));
         }
 
+        /*correction of raw coordinates*/
         if (!priv->calibrate) {
                 DBGOUT(2, "EVTouch: Scaling coordinates\n");
                 xc = v0 - priv->min_x;
@@ -929,6 +959,10 @@ ConvertProc ( LocalDevicePtr local,
                         screen_height = pScrn->currentMode->HDisplay;
                 }
 
+                if ( rotation == RR_Rotate_90 || rotation == RR_Rotate_270 ) {
+                        int tmp = screen_width; screen_width = screen_height;
+                        screen_height = tmp;
+                }
 
                 if (xc < (max_x / 2)) {
                         /*
@@ -1050,7 +1084,10 @@ ConvertProc ( LocalDevicePtr local,
                         tmp = xc;
                         xc = screen_height - yc;
                         yc = tmp;
-                }
+                } else if (priv->rotate == EV_ROTATE_UD) {
+			xc = screen_width - xc;
+			yc = screen_height - yc;
+		}
 
 		switch (rotation) {
 			case RR_Rotate_0:
@@ -1207,9 +1244,7 @@ EVTouchPreInit(InputDriverPtr drv, IDevPtr dev, int flags)
                     priv->diff[i][0], priv->diff[i][1]);
         }
         
-        xf86AlwaysCore(local, TRUE);
         priv->touch_flags = 0;
-
         local->history_size = xf86SetIntOption( local->options, "HistorySize", 0 );
 
         /* prepare to process touch packets */
@@ -1235,6 +1270,9 @@ EVTouchPreInit(InputDriverPtr drv, IDevPtr dev, int flags)
         return (local);
 }
 
+
+
+
 static void
 EVTouchPtrCtrl(DeviceIntPtr device, PtrCtrl *ctrl)
 {
