@@ -42,6 +42,7 @@
 #define EV_ROTATE_NONE 0
 #define EV_ROTATE_CW   1
 #define EV_ROTATE_CCW  2
+#define EV_ROTATE_UD   3
 
 #define EV_AXIS_MIN_RES       0
 #define EV_AXIS_MAX_RES       1024
@@ -94,6 +95,8 @@ typedef struct _EVTouchPrivateRec
 
         int cur_x;
         int cur_y;
+        int raw_x;
+        int raw_y;
         /* pointers to the current viewport coordinates */
         int *pViewPort_X0;    /* Min X */
         int *pViewPort_X1;    /* Max X */
