@@ -34,7 +34,6 @@
 #ifndef NEED_XF86_TYPES
 #define NEED_XF86_TYPES
 #endif
-#include <xf86_ansic.h>
 #include <xf86_OSproc.h>
 #include <xf86Xinput.h>
 #include <exevents.h>
@@ -187,7 +186,7 @@ void libtouchInit(LibTouchRecPtr libtouch, LocalDevicePtr local)
 
         char *str;
 
-        xf86memset(libtouch, 0, sizeof(LibTouchRec));
+        memset(libtouch, 0, sizeof(LibTouchRec));
 
         libtouch->now = GetTimeInMillis();
         libtouch->past = libtouch->now;
@@ -229,7 +228,6 @@ void libtouchInit(LibTouchRecPtr libtouch, LocalDevicePtr local)
                 }
         }
 
-
         dump_configuration();
 }
 
