@@ -1,5 +1,5 @@
 #!/bin/bash
-DISTRI_FILES=".libs/evtouch_drv.so ev_calibrate empty_cursor.xbm ChangeLog TODO README README.calibration INSTALL calibrate.sh Makefile.am configure.ac"
+DISTRI_FILES=".libs/evtouch_drv.so ev_calibrate empty_cursor.xbm ChangeLog TODO README README.calibration INSTALL calibrate.sh Makefile.am autogen.sh configure.ac 69-touchscreen.rules"
 SRC_DISTRI_FILES="*.[ch] Imakefile make_distrib.sh"
 VERSION=$1
 TGT_DIR="evtouch-$1"
